@@ -3,20 +3,15 @@
 #include "dht_router.h"
 
 #include <cassert>
-#include <sstream>
 
 #include "dht_bucket.h"
 #include "dht_tracker.h"
 #include "dht_transaction.h"
-#include "manager.h"
-#include "torrent/connection_manager.h"
-#include "torrent/download_info.h"
 #include "torrent/exceptions.h"
 #include "torrent/net/resolver.h"
 #include "torrent/net/socket_address.h"
 #include "torrent/tracker/dht_controller.h"
 #include "torrent/utils/log.h"
-#include "torrent/utils/thread.h"
 #include "utils/sha1.h"
 
 #define LT_LOG_THIS(log_fmt, ...)                                       \
@@ -26,8 +21,8 @@ namespace torrent {
 
 HashString DhtRouter::zero_id;
 
-DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
-  DhtNode(zero_id, sa),  // actual ID is set later
+DhtRouter::DhtRouter(const Object& cache, const sockaddr* sa) :
+  DhtNode(zero_id, sa), // actual ID is set later
   m_server(this),
   m_curToken(random()),
   m_prevToken(random()) {
@@ -57,7 +52,7 @@ DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
     sha.final_c(data());
   }
 
-  LT_LOG_THIS("creating (address:%s)", sa->pretty_address_str().c_str());
+  LT_LOG_THIS("creating : address:%s", sa_pretty_str(sa).c_str());
 
   set_bucket(new DhtBucket(zero_id, ones_id));
   m_routingTable.emplace(bucket()->id_range_end(), bucket());
@@ -65,7 +60,7 @@ DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
   if (cache.has_key("nodes")) {
     const Object::map_type& nodes = cache.get_key_map("nodes");
 
-    LT_LOG_THIS("adding nodes (size:%zu)", nodes.size());
+    LT_LOG_THIS("adding nodes : size:%zu", nodes.size());
 
     for (const auto& [id, node] : nodes) {
       if (id.length() != HashString::size_data)
@@ -77,11 +72,13 @@ DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
 
   if (m_nodes.size() < num_bootstrap_complete) {
     m_contacts.emplace();
+
     if (cache.has_key("contacts")) {
       for (const auto& contact : cache.get_key_list("contacts")) {
         auto litr = contact.as_list().begin();
         auto host = litr->as_string();
         auto port = std::next(litr)->as_value();
+
         m_contacts->emplace_back(std::move(host), port);
       }
     }
@@ -217,33 +214,34 @@ DhtRouter::contact(const sockaddr* sa, int port) {
   if (!is_active())
     return;
 
-  auto sa_port = sa_copy(sa);
-  sap_set_port(sa_port, port);
+  auto sa_tmp = sa_copy(sa);
+  sap_set_port(sa_tmp, port);
 
-  m_server.ping(zero_id, rak::socket_address::cast_from(sa_port.get()));
+  m_server.ping(zero_id, sa_tmp.get());
 }
 
 // Received a query from the given node. If it has previously replied
 // to one of our queries, consider it alive and update the bucket mtime,
 // otherwise if we could use it in a bucket, try contacting it.
 DhtNode*
-DhtRouter::node_queried(const HashString& id, const rak::socket_address* sa) {
+DhtRouter::node_queried(const HashString& id, const sockaddr* sa) {
   DhtNode* node = get_node(id);
 
-  if (node == NULL) {
+  if (node == nullptr) {
     if (want_node(id))
       m_server.ping(id, sa);
 
-    return NULL;
+    return nullptr;
   }
 
   // If we know the ID but the address is different, don't set the original node
   // active, but neither use this new address to prevent rogue nodes from polluting
   // our routing table with fake source addresses.
-  if (node->address()->sa_inet()->address_n() != sa->sa_inet()->address_n())
-    return NULL;
+  if (!sa_equal_addr(node->address(), sa))
+    return nullptr;
 
   node->queried();
+
   if (node->is_good())
     node->bucket()->touch();
 
@@ -254,7 +252,7 @@ DhtRouter::node_queried(const HashString& id, const rak::socket_address* sa) {
 // Check that it matches the information we have, set that it has replied
 // and update the bucket mtime.
 DhtNode*
-DhtRouter::node_replied(const HashString& id, const rak::socket_address* sa) {
+DhtRouter::node_replied(const HashString& id, const sockaddr* sa) {
   DhtNode* node = get_node(id);
 
   if (node == NULL) {
@@ -268,7 +266,7 @@ DhtRouter::node_replied(const HashString& id, const rak::socket_address* sa) {
       return NULL;
   }
 
-  if (node->address()->sa_inet()->address_n() != sa->sa_inet()->address_n())
+  if (!sa_equal_addr(node->address(), sa))
     return NULL;
 
   node->replied();
@@ -279,7 +277,7 @@ DhtRouter::node_replied(const HashString& id, const rak::socket_address* sa) {
 
 // A node has not replied to one of our queries.
 DhtNode*
-DhtRouter::node_inactive(const HashString& id, const rak::socket_address* sa) {
+DhtRouter::node_inactive(const HashString& id, const sockaddr* sa) {
   DhtNodeList::accessor itr = m_nodes.find(&id);
 
   // If not found add it to some blacklist so we won't try contacting it again immediately?
@@ -290,7 +288,7 @@ DhtRouter::node_inactive(const HashString& id, const rak::socket_address* sa) {
   // however it can also be called if a node replied with an malformed response packet,
   // so check that the address matches so that a rogue node cannot cause other nodes
   // to be considered bad by sending malformed packets.
-  if (itr.node()->address()->sa_inet()->address_n() != sa->sa_inet()->address_n())
+  if (!sa_equal_addr(itr.node()->address(), sa))
     return NULL;
 
   itr.node()->inactive();
@@ -466,10 +464,13 @@ DhtRouter::receive_timeout() {
 }
 
 char*
-DhtRouter::generate_token(const rak::socket_address* sa, int token, char buffer[20]) {
-  Sha1 sha;
-  uint32_t key = sa->sa_inet()->address_n();
+DhtRouter::generate_token(const sockaddr* sa, int token, char buffer[20]) {
+  if (!sa_is_inet(sa))
+    throw internal_error("DhtRouter::generate_token called with non-inet address.");
 
+  uint32_t key = reinterpret_cast<const sockaddr_in*>(sa)->sin_addr.s_addr;
+
+  Sha1 sha;
   sha.init();
   sha.update(&token, sizeof(token));
   sha.update(&key, 4);
@@ -479,7 +480,7 @@ DhtRouter::generate_token(const rak::socket_address* sa, int token, char buffer[
 }
 
 bool
-DhtRouter::token_valid(raw_string token, const rak::socket_address* sa) {
+DhtRouter::token_valid(raw_string token, const sockaddr* sa) const {
   if (token.size() != size_token)
     return false;
 
@@ -496,10 +497,11 @@ DhtRouter::token_valid(raw_string token, const rak::socket_address* sa) {
 }
 
 DhtNode*
-DhtRouter::find_node(const rak::socket_address* sa) {
-  for (const auto& [id, node] : m_nodes)
-    if (node->address()->sa_inet()->address_n() == sa->sa_inet()->address_n())
+DhtRouter::find_node(const sockaddr* sa) {
+  for (const auto& [id, node] : m_nodes) {
+    if (sa_equal_addr(node->address(), sa))
       return node;
+  }
 
   return nullptr;
 }
@@ -580,13 +582,18 @@ DhtRouter::delete_node(const DhtNodeList::accessor& itr) {
 
 void
 DhtRouter::bootstrap() {
+  if (!m_contacts.has_value())
+    return;
+
   // Contact up to 8 nodes from the contact list (newest first).
   for (int count = 0; count < 8 && !m_contacts->empty(); count++) {
     // Currently discarding SOCK_DGRAM.
-    this_thread::resolver()->resolve_specific(this, m_contacts->back().first.c_str(), rak::socket_address::pf_inet, [this](auto sa, int) {
+    auto f = [this](const auto& sa, int) {
       if (sa != nullptr)
         contact(sa.get(), m_contacts->back().second);
-    });
+    };
+
+    this_thread::resolver()->resolve_specific(this, m_contacts->back().first, AF_INET, f);
 
     m_contacts->pop_back();
   }
@@ -599,9 +606,10 @@ DhtRouter::bootstrap() {
 
   // Aggressively ping all questionable nodes in our own bucket to weed
   // out bad nodes as early as possible and make room for fresh nodes.
-  for (auto node : *bucket())
+  for (auto node : *bucket()) {
     if (!node->is_good())
       m_server.ping(node->id(), node->address());
+  }
 
   // Also bootstrap a random bucket, if there are others.
   if (m_routingTable.size() < 2)
@@ -627,7 +635,7 @@ DhtRouter::bootstrap_bucket(const DhtBucket* bucket) {
 
   if (bucket == this->bucket()) {
     contactId = id();
-    contactId[contactId.size() - 1] ^= 1;
+    contactId[torrent::HashString::size() - 1] ^= 1;
   } else {
     bucket->get_random_id(&contactId);
   }
@@ -635,4 +643,4 @@ DhtRouter::bootstrap_bucket(const DhtBucket* bucket) {
   m_server.find_node(*bucket, contactId);
 }
 
-}
+} // namespace torrent
