@@ -22,10 +22,6 @@
 #include "utils/diffie_hellman.h"
 #include "utils/sha1.h"
 
-#define LT_LOG(log_fmt, ...)                                            \
-  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt,     \
-               m_address.pretty_address_str().c_str(), __VA_ARGS__);
-
 #if DISABLED__USE_EXTRA_DEBUG
 #define LT_LOG_EXTRA_DEBUG_SA(sa, log_fmt, ...)                         \
   lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt, sap_pretty_str(m_address).c_str(), __VA_ARGS__);
@@ -126,7 +122,6 @@ Handshake::deactivate_connection() {
   m_state = INACTIVE;
 
   this_thread::scheduler()->erase(&m_task_timeout);
-
   this_thread::poll()->remove_and_close(this);
 }
 
@@ -323,6 +318,10 @@ Handshake::read_encryption_skey() {
 
   validate_download();
 
+  // We don't allow encrypted connections for meta-data downloads.
+  if (m_download->info()->is_meta_download())
+    throw handshake_error(ConnectionManager::handshake_dropped, e_handshake_invalid_encryption);
+
   std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.get());
 
   m_encryption.initialize_encrypt(m_download->info()->hash().c_str(), m_incoming);
