@@ -193,7 +193,7 @@ protected:
   DataBuffer          m_extensionMessage;
   uint32_t            m_extensionOffset;
 
-  EncryptBuffer*      m_encryptBuffer{};
+  std::unique_ptr<EncryptBuffer> m_encryptBuffer;
   EncryptionInfo      m_encryption;
   ProtocolExtension*  m_extensions{};
 
@@ -236,6 +236,6 @@ PeerConnectionBase::write_insert_poll_safe() {
   this_thread::poll()->insert_write(this);
 }
 
-}
+} // namespace torrent
 
 #endif
