@@ -119,7 +119,7 @@ TransferList::hash_succeeded(uint32_t index, Chunk* chunk) {
 struct transfer_list_compare_data {
   transfer_list_compare_data(Chunk* chunk, const Piece& p) : m_chunk(chunk), m_piece(p) { }
 
-  bool operator () (BlockFailed::value_type failed) {
+  bool operator () (BlockFailed::value_type failed) const {
     return m_chunk->compare_buffer(failed.first, m_piece.offset(), m_piece.length());
   }
 
@@ -251,4 +251,4 @@ TransferList::retry_most_popular(BlockList* blockList, Chunk* chunk) {
   m_slot_completed(blockList->index());
 }
 
-}
+} // namespace torrent
