@@ -5,9 +5,9 @@
 #include "torrent/exceptions.h"
 #include "torrent/hash_string.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstdarg>
 #include <zlib.h>
 
 #include <algorithm>
@@ -35,7 +35,7 @@ struct log_gz_output {
   log_gz_output(const char* filename, bool append) :
       gz_file(gzopen(filename, append ? "a" : "w"), gzclose) {}
 
-  bool is_valid() { return gz_file != Z_NULL; }
+  bool is_valid() const { return gz_file != Z_NULL; }
 
   // bool set_buffer(unsigned size) { return gzbuffer(gz_file.get(), size) == 0; }
 
@@ -44,21 +44,20 @@ struct log_gz_output {
 
 using log_cache_list  = std::vector<log_cache_entry>;
 using log_child_list  = std::vector<std::pair<int, int>>;
-using log_slot_list   = std::vector<log_slot>;
-using log_output_list = std::vector<std::pair<std::string, log_slot>>;
 
-log_output_list log_outputs LIBTORRENT_EXPORT;
-log_child_list  log_children;
-log_cache_list  log_cache;
 log_group_list  log_groups;
-std::mutex      log_mutex;
+log_output_list log_outputs;
 
-const char log_level_char[] = { 'C', 'E', 'W', 'N', 'I', 'D' };
+static log_cache_list  log_cache;
+static log_child_list  log_children;
+static std::mutex      log_mutex;
+
+static const char log_level_char[] = { 'C', 'E', 'W', 'N', 'I', 'D' };
 
 // Removing logs always triggers a check if we got any un-used
 // log_output objects.
 
-void
+static void
 log_update_child_cache(int index) {
   auto first =
     std::find_if(log_children.begin(), log_children.end(), [index](const auto& pair) { return pair >= std::make_pair(index, 0); });
@@ -83,7 +82,7 @@ log_update_child_cache(int index) {
     log_update_child_cache(index);
 }
 
-void
+static void
 log_rebuild_cache() {
   std::for_each(log_groups.begin(), log_groups.end(), std::mem_fn(&log_group::clear_cached_outputs));
 
@@ -186,14 +185,12 @@ log_initialize() {
   LOG_CASCADE(LOG_SOCKET_CRITICAL);
   LOG_CASCADE(LOG_STORAGE_CRITICAL);
   LOG_CASCADE(LOG_THREAD_CRITICAL);
-  LOG_CASCADE(LOG_TRACKER_CRITICAL);
   LOG_CASCADE(LOG_TORRENT_CRITICAL);
 
   LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_PEER_CRITICAL);
   LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_SOCKET_CRITICAL);
   LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_STORAGE_CRITICAL);
   LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_THREAD_CRITICAL);
-  LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_TRACKER_CRITICAL);
   LOG_CHILDREN_CASCADE(LOG_CRITICAL, LOG_TORRENT_CRITICAL);
 
   LOG_LINK(LOG_CONNECTION, LOG_CONNECTION_BIND);
@@ -202,7 +199,10 @@ log_initialize() {
   LOG_LINK(LOG_CONNECTION, LOG_CONNECTION_HANDSHAKE);
   LOG_LINK(LOG_CONNECTION, LOG_CONNECTION_LISTEN);
 
-  LOG_LINK(LOG_DHT_ALL, LOG_DHT_MANAGER);
+  LOG_LINK(LOG_DHT, LOG_DHT_ERROR);
+  LOG_LINK(LOG_DHT, LOG_DHT_CONTROLLER);
+  LOG_LINK(LOG_DHT_ALL, LOG_DHT_ERROR);
+  LOG_LINK(LOG_DHT_ALL, LOG_DHT_CONTROLLER);
   LOG_LINK(LOG_DHT_ALL, LOG_DHT_NODE);
   LOG_LINK(LOG_DHT_ALL, LOG_DHT_ROUTER);
   LOG_LINK(LOG_DHT_ALL, LOG_DHT_SERVER);
@@ -225,7 +225,7 @@ log_cleanup() {
   log_cache.clear();
 }
 
-log_output_list::iterator
+static log_output_list::iterator
 log_find_output_name(const char* name) {
   auto itr = log_outputs.begin();
   auto last = log_outputs.end();
@@ -308,26 +308,26 @@ log_remove_child([[maybe_unused]] int group, [[maybe_unused]] int child) {
   // Remove from all groups, then modify all outputs.
 }
 
-void
+static void
 log_file_write(const std::shared_ptr<std::ofstream>& outfile, const char* data, size_t length, int group) {
   // Add group name, data, etc as flags.
 
   // Normal groups are nul-terminated strings.
   if (group >= LOG_NON_CASCADING) {
-    *outfile << this_thread::cached_seconds().count() << ' ' << data << std::endl;
+    *outfile << this_thread::cached_seconds().count() << ' ' << data << '\n';
   } else if (group >= 0) {
-    *outfile << this_thread::cached_seconds().count() << ' ' << log_level_char[group % 6] << ' ' << data << std::endl;
+    *outfile << this_thread::cached_seconds().count() << ' ' << log_level_char[group % 6] << ' ' << data << '\n';
   } else if (group == -1) {
-    *outfile << "---DUMP---" << std::endl;
+    *outfile << "---DUMP---" << '\n';
     if (length != 0) {
       outfile->rdbuf()->sputn(data, length);
-      *outfile << std::endl;
+      *outfile << '\n';
     }
-    *outfile << "---END---" << std::endl;
+    *outfile << "---END---" << '\n';
   }
 }
 
-void
+static void
 log_gz_file_write(const std::shared_ptr<log_gz_output>& outfile, const char* data, size_t length, int group) {
   char buffer[64];
 
@@ -335,7 +335,7 @@ log_gz_file_write(const std::shared_ptr<log_gz_output>& outfile, const char* dat
   if (group >= 0) {
     int buffer_length = snprintf(buffer, 64,
                                  (group >= LOG_NON_CASCADING) ? ("%" PRIi64 " ") : ("%" PRIi64 " %c "),
-                                 (int64_t)this_thread::cached_seconds().count(),
+                                 static_cast<int64_t>(this_thread::cached_seconds().count()),
                                  log_level_char[group % 6]);
 
     if (buffer_length > 0)
@@ -380,4 +380,4 @@ log_open_gz_file_output(const char* name, const char* filename, bool append) {
   log_open_output(name, [outfile](auto d, auto l, auto g) { log_gz_file_write(outfile, d, l, g); });
 }
 
-}
+} // namespace torrent
