@@ -263,12 +263,9 @@ TrackerController::send_update_event() {
 
 // Currently being used by send_event, fixme.
 void
-TrackerController::close(int flags) {
+TrackerController::close() {
   m_flags &= ~(flag_requesting | flag_promiscuous_mode);
 
-  if ((flags & (close_disown_stop | close_disown_completed)))
-    m_tracker_list->disown_all_including(close_disown_stop | close_disown_completed);
-
   m_tracker_list->close_all();
   this_thread::scheduler()->erase(&m_task_timeout);
 }
@@ -410,7 +407,7 @@ tracker_next_timeout_promiscuous(const tracker::Tracker& tracker) {
   return std::max(use_interval - since_last, 0);
 }
 
-TrackerList::iterator
+static TrackerList::iterator
 tracker_find_preferred(TrackerList::iterator first, TrackerList::iterator last, uint32_t* next_timeout) {
   auto preferred = last;
   uint32_t preferred_time_last = ~uint32_t();
@@ -597,7 +594,7 @@ TrackerController::receive_failure(const tracker::Tracker& tracker, const std::s
 }
 
 void
-TrackerController::receive_scrape([[maybe_unused]] const tracker::Tracker& tracker) {
+TrackerController::receive_scrape([[maybe_unused]] const tracker::Tracker& tracker) const {
   if (!(m_flags & flag_active)) {
     return;
   }
@@ -631,4 +628,4 @@ TrackerController::receive_tracker_disabled(const tracker::Tracker& tb) {
     m_slot_tracker_disabled(tb);
 }
 
-}
+} // namespace torrent
