@@ -12,6 +12,7 @@
 #include "torrent/exceptions.h"
 #include "torrent/net/http_stack.h"
 #include "torrent/net/network_config.h"
+#include "torrent/net/network_manager.h"
 #include "torrent/net/socket_address.h"
 #include "torrent/object_stream.h"
 #include "torrent/utils/log.h"
@@ -98,6 +99,8 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
   m_data = std::make_unique<std::stringstream>();
   m_get.reset(request_url, m_data);
 
+  // TODO: Should bind address here...
+
   if (is_block_ipv4 && is_block_ipv6) {
     throw torrent::internal_error("Cannot send tracker event, both IPv4 and IPv6 are blocked.");
   } else if (is_block_ipv4) {
@@ -106,6 +109,8 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
     m_get.use_ipv4();
   } else if (is_prefer_ipv6) {
     m_get.prefer_ipv6();
+  } else {
+    m_get.prefer_ipv4();
   }
 
   LT_LOG_DUMP(request_url.c_str(), request_url.size(),
@@ -186,7 +191,7 @@ TrackerHttp::request_announce_url(tracker::TrackerState::event_enum state, Track
   if (params.numwant >= 0 && state != tracker::TrackerState::EVENT_STOPPED)
     s << "&numwant=" << params.numwant;
 
-  s << "&port=" << config::network_config()->listen_port_or_throw()
+  s << "&port=" << runtime::network_manager()->listen_port_or_throw()
     << "&uploaded=" << params.uploaded_adjusted
     << "&downloaded=" << params.completed_adjusted
     << "&left=" << params.download_left;
